Struct diem_crypto::test_utils::TestDiemCrypto [−][src]
pub struct TestDiemCrypto(pub String);Expand description
This struct provides a means of testing signing and verification through BCS serialization and domain separation
Tuple Fields
0: StringTrait Implementations
type Hasher = TestDiemCryptoHasher
type Hasher = TestDiemCryptoHasher
The associated Hasher type which comes with a unique salt for this type.
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more